@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -451,6 +451,15 @@ class E5ToolBarManager(QObject):
             if action in self.__categoryToActions[category]:
                 self.__categoryToActions[category].remove(action)
     
+    def removeCategoryActions(self, category):
+        """
+        Public method to remove the actions belonging to a category.
+        
+        @param category category for the actions (string)
+        """
+        for action in self.categoryActions(category):
+            self.removeAction(action)
+    
     def saveState(self, version=0):
         """
         Public method to save the state of the toolbar manager.
@@ -470,18 +479,18 @@ class E5ToolBarManager(QObject):
         for tbID in self.__defaultToolBars:
             tb = self.__allToolBars[tbID]
             if tb.objectName():
-                stream.writeString(tb.objectName().encode())
+                stream.writeString(tb.objectName().encode("utf-8"))
             else:
-                stream.writeString(tb.windowTitle().encode())
+                stream.writeString(tb.windowTitle().encode("utf-8"))
             stream.writeUInt16(len(self.__toolBars[tbID]))
             for action in self.__toolBars[tbID]:
                 if action is not None:
                     if action.objectName():
-                        stream.writeString(action.objectName().encode())
+                        stream.writeString(action.objectName().encode("utf-8"))
                     else:
-                        stream.writeString(action.text().encode())
+                        stream.writeString(action.text().encode("utf-8"))
                 else:
-                    stream.writeString("".encode())
+                    stream.writeString("".encode("utf-8"))
         
         # save the custom toolbars
         stream.writeUInt16(E5ToolBarManager.CustomToolBarMarker)
@@ -489,17 +498,18 @@ class E5ToolBarManager(QObject):
         for tbID in self.__toolBars:
             if tbID not in self.__defaultToolBars:
                 tb = self.__allToolBars[tbID]
-                stream.writeString(tb.objectName().encode())
-                stream.writeString(tb.windowTitle().encode())
+                stream.writeString(tb.objectName().encode("utf-8"))
+                stream.writeString(tb.windowTitle().encode("utf-8"))
                 stream.writeUInt16(len(self.__toolBars[tbID]))
                 for action in self.__toolBars[tbID]:
                     if action is not None:
                         if action.objectName():
-                            stream.writeString(action.objectName().encode())
+                            stream.writeString(action.objectName()
+                                               .encode("utf-8"))
                         else:
-                            stream.writeString(action.text().encode())
+                            stream.writeString(action.text().encode("utf-8"))
                     else:
-                        stream.writeString("".encode())
+                        stream.writeString("".encode("utf-8"))
         
         return data
     
@@ -639,7 +649,7 @@ class E5ToolBarManager(QObject):
         """
         Public method to get the actions belonging to a category.
         
-        @param category category for the toolbar (string)
+        @param category category for the actions (string)
         @return list of actions (list of QAction)
         """
         if category not in self.__categoryToActions:
