@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -213,8 +213,8 @@ class DownloadItem(QWidget, Ui_DownloadItem):
             self.__autoOpen = dlg.getAction() == "open"
             if PYQT_VERSION_STR >= "5.0.0":
                 from PyQt5.QtCore import QStandardPaths
-                tempLocation = QStandardPaths.storageLocation(
-                    QStandardPaths.TempLocation)
+                tempLocation = QStandardPaths.standardLocations(
+                    QStandardPaths.TempLocation)[0]
             else:
                 from PyQt5.QtGui import QDesktopServices
                 tempLocation = QDesktopServices.storageLocation(
