@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -79,7 +79,8 @@ class ConfigurationWidget(QWidget):
     HelpBrowserMode = 1
     TrayStarterMode = 2
     
-    def __init__(self, parent=None, fromEric=True, displayMode=DefaultMode):
+    def __init__(self, parent=None, fromEric=True, displayMode=DefaultMode,
+                 expandedEntries=[]):
         """
         Constructor
         
@@ -89,6 +90,8 @@ class ConfigurationWidget(QWidget):
         @keyparam displayMode mode of the configuration dialog
             (DefaultMode, HelpBrowserMode, TrayStarterMode)
         @exception RuntimeError raised to indicate an invalid dialog mode
+        @keyparam expandedEntries list of entries to be shown expanded
+            (list of strings)
         """
         assert displayMode in (
             ConfigurationWidget.DefaultMode,
@@ -117,9 +120,9 @@ class ConfigurationWidget(QWidget):
                 # key : [display string, pixmap name, dialog module name or
                 #        page creation function, parent key,
                 #        reference to configuration page (must always be last)]
-                # The dialog module must have the module function create to
+                # The dialog module must have the module function 'create' to
                 # create the configuration page. This must have the method
-                # save to save the settings.
+                # 'save' to save the settings.
                 "applicationPage":
                 [self.tr("Application"), "preferences-application.png",
                  "ApplicationPage", None, None],
@@ -141,6 +144,12 @@ class ConfigurationWidget(QWidget):
                 "ircPage":
                 [self.tr("IRC"), "irc.png",
                  "IrcPage", None, None],
+                "logViewerPage":
+                [self.tr("Log-Viewer"), "preferences-logviewer.png",
+                 "LogViewerPage", None, None],
+                "mimeTypesPage":
+                [self.tr("Mimetypes"), "preferences-mimetypes.png",
+                 "MimeTypesPage", None, None],
                 "networkPage":
                 [self.tr("Network"), "preferences-network.png",
                  "NetworkPage", None, None],
@@ -193,9 +202,6 @@ class ConfigurationWidget(QWidget):
                 "debuggerPython3Page":
                 [self.tr("Python3"), "preferences-pyDebugger.png",
                  "DebuggerPython3Page", "0debuggerPage", None],
-                "debuggerRubyPage":
-                [self.tr("Ruby"), "preferences-rbDebugger.png",
-                 "DebuggerRubyPage", "0debuggerPage", None],
                 
                 "0editorPage":
                 [self.tr("Editor"), "preferences-editor.png",
@@ -263,12 +269,14 @@ class ConfigurationWidget(QWidget):
                 [self.tr("Properties"), "preferences-properties.png",
                  "EditorPropertiesPage", "1editorLexerPage", None],
                 
+                "1editorMouseClickHandlers":
+                [self.tr("Mouse Click Handlers"),
+                 "preferences-mouse-click-handler.png",
+                 "EditorMouseClickHandlerPage", "0editorPage", None],
+                
                 "0helpPage":
                 [self.tr("Help"), "preferences-help.png",
                  None, None, None],
-                "helpAppearancePage":
-                [self.tr("Appearance"), "preferences-styles.png",
-                 "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
@@ -277,9 +285,6 @@ class ConfigurationWidget(QWidget):
                 [self.tr("Help Viewers"),
                  "preferences-helpviewers.png",
                  "HelpViewersPage", "0helpPage", None],
-                "helpWebBrowserPage":
-                [self.tr("eric6 Web Browser"), "ericWeb.png",
-                 "HelpWebBrowserPage", "0helpPage", None],
                 
                 "0projectPage":
                 [self.tr("Project"), "preferences-project.png",
@@ -305,17 +310,37 @@ class ConfigurationWidget(QWidget):
                 [self.tr("Viewmanager"), "preferences-viewmanager.png",
                  "ViewmanagerPage", "0interfacePage", None],
             }
+            try:
+                from PyQt5 import QtWebKit      # __IGNORE_WARNING__
+                self.configItems.update({
+                    "helpAppearancePage":
+                    [self.tr("Appearance"), "preferences-styles.png",
+                     "HelpAppearancePage", "0helpPage", None],
+                    "helpFlashCookieManagerPage":
+                    [self.tr("Flash Cookie Manager"),
+                     "flashCookie16.png",
+                     "HelpFlashCookieManagerPage", "0helpPage", None],
+                    "helpVirusTotalPage":
+                    [self.tr("VirusTotal Interface"), "virustotal.png",
+                     "HelpVirusTotalPage", "0helpPage", None],
+                    "helpWebBrowserPage":
+                    [self.tr("eric6 Web Browser"), "ericWeb.png",
+                     "HelpWebBrowserPage", "0helpPage", None],
+                })
+            except ImportError:
+                pass
             
             self.configItems.update(
                 e5App().getObject("PluginManager").getPluginConfigData())
+        
         elif displayMode == ConfigurationWidget.HelpBrowserMode:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or
                 #        page creation function, parent key,
                 #        reference to configuration page (must always be last)]
-                # The dialog module must have the module function create to
+                # The dialog module must have the module function 'create' to
                 # create the configuration page. This must have the method
-                # save to save the settings.
+                # 'save' to save the settings.
                 "interfacePage":
                 [self.tr("Interface"), "preferences-interface.png",
                  "HelpInterfacePage", None, None],
@@ -332,33 +357,49 @@ class ConfigurationWidget(QWidget):
                 "0helpPage":
                 [self.tr("Help"), "preferences-help.png",
                  None, None, None],
-                "helpAppearancePage":
-                [self.tr("Appearance"), "preferences-styles.png",
-                 "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
                  "HelpDocumentationPage", "0helpPage", None],
-                "helpWebBrowserPage":
-                [self.tr("eric6 Web Browser"), "ericWeb.png",
-                 "HelpWebBrowserPage", "0helpPage", None],
             }
+            try:
+                from PyQt5 import QtWebKit      # __IGNORE_WARNING__
+                self.configItems.update({
+                    "helpAppearancePage":
+                    [self.tr("Appearance"), "preferences-styles.png",
+                     "HelpAppearancePage", "0helpPage", None],
+                    "helpFlashCookieManagerPage":
+                    [self.tr("Flash Cookie Manager"),
+                     "flashCookie16.png",
+                     "HelpFlashCookieManagerPage", "0helpPage", None],
+                    "helpVirusTotalPage":
+                    [self.tr("VirusTotal Interface"), "virustotal.png",
+                     "HelpVirusTotalPage", "0helpPage", None],
+                    "helpWebBrowserPage":
+                    [self.tr("eric6 Web Browser"), "ericWeb.png",
+                     "HelpWebBrowserPage", "0helpPage", None],
+                })
+            except ImportError:
+                pass
+        
         elif displayMode == ConfigurationWidget.TrayStarterMode:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or
                 #        page creation function, parent key,
                 #        reference to configuration page (must always be last)]
-                # The dialog module must have the module function create to
+                # The dialog module must have the module function 'create' to
                 # create the configuration page. This must have the method
-                # save to save the settings.
+                # 'save' to save the settings.
                 "trayStarterPage":
                 [self.tr("Tray Starter"), "erict.png",
                  "TrayStarterPage", None, None],
             }
+        
         else:
             raise RuntimeError("Illegal mode value: {0}".format(displayMode))
         
         # generate the list entries
+        self.__expandedEntries = []
         for key in sorted(self.configItems.keys()):
             pageData = self.configItems[key]
             if pageData[3]:
@@ -371,7 +412,10 @@ class ConfigurationWidget(QWidget):
             self.itmDict[key] = ConfigurationPageItem(pitm, pageData[0], key,
                                                       pageData[1])
             self.itmDict[key].setData(0, Qt.UserRole, key)
-            self.itmDict[key].setExpanded(True)
+            if (not self.fromEric or
+                displayMode != ConfigurationWidget.DefaultMode or
+                    key in expandedEntries):
+                self.itmDict[key].setExpanded(True)
         self.configList.sortByColumn(0, Qt.AscendingOrder)
         
         # set the initial size of the splitter
@@ -417,14 +461,14 @@ class ConfigurationWidget(QWidget):
         self.leftVBoxLayout.setContentsMargins(0, 0, 0, 0)
         self.leftVBoxLayout.setSpacing(0)
         self.leftVBoxLayout.setObjectName("leftVBoxLayout")
-        self.configListFilter = E5ClearableLineEdit(
-            self, self.tr("Enter filter text..."))
-        self.configListFilter.setObjectName("configListFilter")
-        self.leftVBoxLayout.addWidget(self.configListFilter)
+        self.configListSearch = E5ClearableLineEdit(
+            self, self.tr("Enter search text..."))
+        self.configListSearch.setObjectName("configListSearch")
+        self.leftVBoxLayout.addWidget(self.configListSearch)
         self.configList = QTreeWidget()
         self.configList.setObjectName("configList")
         self.leftVBoxLayout.addWidget(self.configList)
-        self.configListFilter.textChanged.connect(self.__filterTextChanged)
+        self.configListSearch.textChanged.connect(self.__searchTextChanged)
         
         self.scrollArea = QScrollArea(self.configSplitter)
         self.scrollArea.setFrameShape(QFrame.NoFrame)
@@ -495,36 +539,36 @@ class ConfigurationWidget(QWidget):
         
         self.configList.setFocus()
     
-    def __filterTextChanged(self, filter):
+    def __searchTextChanged(self, text):
         """
-        Private slot to handle a change of the filter.
+        Private slot to handle a change of the search text.
         
-        @param filter text of the filter line edit (string)
+        @param text text to search for (string)
         """
-        self.__filterChildItems(self.configList.invisibleRootItem(), filter)
+        self.__searchChildItems(self.configList.invisibleRootItem(), text)
     
-    def __filterChildItems(self, parent, filter):
+    def __searchChildItems(self, parent, text):
         """
-        Private method to filter child items based on a filter string.
+        Private method to enable child items based on a search string.
         
         @param parent reference to the parent item (QTreeWidgetItem)
-        @param filter filter string (string)
-        @return flag indicating a visible child item (boolean)
+        @param text text to search for (string)
+        @return flag indicating an enabled child item (boolean)
         """
-        childVisible = False
-        filter = filter.lower()
+        childEnabled = False
+        text = text.lower()
         for index in range(parent.childCount()):
             itm = parent.child(index)
             if itm.childCount() > 0:
-                visible = self.__filterChildItems(itm, filter) or \
-                    filter == "" or filter in itm.text(0).lower()
+                enable = self.__searchChildItems(itm, text) or \
+                    text == "" or text in itm.text(0).lower()
             else:
-                visible = filter == "" or filter in itm.text(0).lower()
-            if visible:
-                childVisible = True
-            itm.setHidden(not visible)
+                enable = text == "" or text in itm.text(0).lower()
+            if enable:
+                childEnabled = True
+            itm.setDisabled(not enable)
         
-        return childVisible
+        return childEnabled
     
     def __initLexers(self):
         """
@@ -720,6 +764,7 @@ class ConfigurationWidget(QWidget):
             self.preferencesChanged.emit()
             if savedState is not None:
                 page.setState(savedState)
+            page.polishPage()
         
     @pyqtSlot()
     def on_resetButton_clicked(self):
@@ -738,6 +783,36 @@ class ConfigurationWidget(QWidget):
             self.showConfigurationPageByName(pageName)
             if savedState is not None:
                 self.configStack.currentWidget().setState(savedState)
+        
+    def getExpandedEntries(self):
+        """
+        Public method to get a list of expanded entries.
+        
+        @return list of expanded entries (list of string)
+        """
+        return self.__expandedEntries
+    
+    @pyqtSlot(QTreeWidgetItem)
+    def on_configList_itemCollapsed(self, item):
+        """
+        Private slot handling a list entry being collapsed.
+        
+        @param item reference to the collapsed item (QTreeWidgetItem)
+        """
+        pageName = item.data(0, Qt.UserRole)
+        if pageName in self.__expandedEntries:
+            self.__expandedEntries.remove(pageName)
+    
+    @pyqtSlot(QTreeWidgetItem)
+    def on_configList_itemExpanded(self, item):
+        """
+        Private slot handling a list entry being expanded.
+        
+        @param item reference to the expanded item (QTreeWidgetItem)
+        """
+        pageName = item.data(0, Qt.UserRole)
+        if pageName not in self.__expandedEntries:
+            self.__expandedEntries.append(pageName)
 
 
 class ConfigurationDialog(QDialog):
@@ -756,7 +831,8 @@ class ConfigurationDialog(QDialog):
     TrayStarterMode = ConfigurationWidget.TrayStarterMode
     
     def __init__(self, parent=None, name=None, modal=False,
-                 fromEric=True, displayMode=ConfigurationWidget.DefaultMode):
+                 fromEric=True, displayMode=ConfigurationWidget.DefaultMode,
+                 expandedEntries=[]):
         """
         Constructor
         
@@ -767,6 +843,8 @@ class ConfigurationDialog(QDialog):
             eric6 ide (boolean)
         @keyparam displayMode mode of the configuration dialog
             (DefaultMode, HelpBrowserMode, TrayStarterMode)
+        @keyparam expandedEntries list of entries to be shown expanded
+            (list of strings)
         """
         super(ConfigurationDialog, self).__init__(parent)
         if name:
@@ -779,7 +857,8 @@ class ConfigurationDialog(QDialog):
         self.layout.setSpacing(0)
         
         self.cw = ConfigurationWidget(self, fromEric=fromEric,
-                                      displayMode=displayMode)
+                                      displayMode=displayMode,
+                                      expandedEntries=expandedEntries)
         size = self.cw.size()
         self.layout.addWidget(self.cw)
         self.resize(size)
@@ -821,6 +900,14 @@ class ConfigurationDialog(QDialog):
         """
         return self.cw.getConfigurationPageName()
         
+    def getExpandedEntries(self):
+        """
+        Public method to get a list of expanded entries.
+        
+        @return list of expanded entries (list of string)
+        """
+        return self.cw.getExpandedEntries()
+        
     def setPreferences(self):
         """
         Public method called to store the selected values into the preferences
